<?php

namespace Tests\Feature;

use App\Jobs\JudgeSubmission;
use App\Models\Submission;
use App\Models\User;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Support\Facades\Queue;
use Tests\TestCase;

class SubmissionsApiSampleTest extends TestCase
{
    use RefreshDatabase;

    public function test_get_submissions_without_bearer_token()
    {
        $response = $this->withHeader('Accept','application/json')
            ->get('/api/submissions');

        $response->assertStatus(401);
    }

    public function test_get_submissions_with_bearer_token()
    {
        $user = User::factory()->create();
        $token = $user->createToken('Judge API');
        $submissions = Submission::factory()->count(3)->for($user)->create();
        $submissions->each(function ($submission) {
            $submission->refresh();
        });
        $response = $this->withHeaders([
            'Accept' => 'application/json',
            'Authorization' => 'Bearer ' . $token->plainTextToken,
        ])->get('/api/submissions');

        $response->assertOk()
                 ->assertExactJson($submissions->toArray());
    }
}
